@@ -1,24 +1,25 @@
 __all__ = [
-    "PubSubItem",
-    "PubSub",
-    "ThreadTaskIdComposer",
-    "ThreadSafeAsyncioEvent",
-    "ToLoop",
-    "MultiprocessingLogging",
-    "peek_stdout",
-    "peek_stderr",
-    "peek_textio",
-    "ExcThread",
-    "ThreadTaskDoneCallback",
-    "ThreadDoneCallback",
-    "TaskDoneCallback",
-    "current_task_or_thread",
-    "to_thread",
-    "agen_with_wait",
-    "merge_aiters",
-    "profile_func",
-    "run_in_process",
-    "RunInProcess",
+    'ThreadDoneCallback',
+    'TaskDoneCallback',
+    'ThreadTaskDoneCallback',
+    'agen_with_wait',
+    'current_task_or_thread',
+    'merge_aiters',
+    'to_thread',
+    'ToLoop',
+    'MultiprocessingLogging',
+    'peek_stderr',
+    'peek_stdout',
+    'peek_textio',
+    'profile_func',
+    'PubSub',
+    'PubSubItem',
+    'ExecutorFactory',
+    'Running',
+    'run_in_process',
+    'ExcThread',
+    'ThreadSafeAsyncioEvent',
+    'ThreadTaskIdComposer',
 ]
 
 from .done_callback import TaskDoneCallback, ThreadDoneCallback, ThreadTaskDoneCallback
@@ -28,7 +29,7 @@ from .multiprocessing_logging import MultiprocessingLogging
 from .peek import peek_stderr, peek_stdout, peek_textio
 from .profile import profile_func
 from .pubsub import PubSub, PubSubItem
-from .run import RunInProcess, run_in_process
+from .run import ExecutorFactory, Running, run_in_process
 from .thread_exception import ExcThread
 from .thread_safe_event import ThreadSafeAsyncioEvent
 from .thread_task_id import ThreadTaskIdComposer
